#
# spec file for package python-google-cloud-logging
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-google-cloud-logging
Version:        3.12.1
Release:        1.1
Summary:        Stackdriver Logging API client library
License:        Apache-2.0
URL:            https://github.com/googleapis/python-logging
Source:         https://files.pythonhosted.org/packages/source/g/google_cloud_logging/google_cloud_logging-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module google-api-core >= 1.33.2}
BuildRequires:  %{python_module google-auth >= 2.14.1}
BuildRequires:  %{python_module google-cloud-appengine-logging >= 0.1.3}
BuildRequires:  %{python_module google-cloud-audit-log >= 0.3.1}
BuildRequires:  %{python_module google-cloud-core >= 2.0.0}
BuildRequires:  %{python_module grpc-google-iam-v1 >= 0.12.4}
BuildRequires:  %{python_module opentelemetry-api >= 1.9.0}
BuildRequires:  %{python_module proto-plus >= 1.22.0}
BuildRequires:  %{python_module protobuf >= 3.20.2}
# /SECTION
BuildRequires:  fdupes
Requires:       python-google-api-core >= 1.33.2
Requires:       python-google-auth >= 2.14.1
Requires:       python-google-cloud-appengine-logging >= 0.1.3
Requires:       python-google-cloud-audit-log >= 0.3.1
Requires:       python-google-cloud-core >= 2.0.0
Requires:       python-grpc-google-iam-v1 >= 0.12.4
Requires:       python-opentelemetry-api >= 1.9.0
Requires:       python-proto-plus >= 1.22.0
Requires:       python-protobuf >= 3.20.2
Suggests:       python-proto-plus >= 1.22.2
BuildArch:      noarch
%python_subpackages

%description
Stackdriver Logging API client library

%prep
%autosetup -p1 -n google_cloud_logging-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/google/cloud/logging*
%{python_sitelib}/google_cloud_logging-%{version}.dist-info

%changelog
* Fri Apr 25 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.12.1
  * Make logging handler close conditional to having the transport opened (#990)
- from version 3.12.0
  * Add REST Interceptors which support reading metadata
  * Add support for opt-in debug logging
  * Added flushes/close functionality to logging handlers (#917)
  * Allow protobuf 6.x (#977)
  * **deps:** Require google-cloud-audit-log >= 0.3.1 (#979)
  * Fix typing issue with gRPC metadata when key ends in -bin
  * Added documentation on log_level and excluded_loggers params in setup_logging (#971)
  * Update README to break infinite redirect loop (#972)
- from version 3.11.4
  * Made `write_entries` raise `ValueError` on `ParseError`s (#958)
  * Require proto-plus >= 1.25 for Python 3.13 (#955)
- from version 3.11.3
  * 16-bit hexadecimal formatting for XCTC span IDs (#946)
- from version 3.11.2
  * **deps:** Require google-cloud-appengine-logging >= 0.1.3
  * **deps:** Require google-cloud-audit-log >= 0.2.4
  * **deps:** Require opentelemetry-api >= 1.9.0
  * Fixed type hinting issue with specifying Transport class (#930)
- from version 3.11.1
  * Allow protobuf 5.x (#888)
- from version 3.11.0
  * OpenTelemetry trace/spanID integration for Python handlers (#889)
  * Added environment specific labels to client library when running
    in Cloud Run Jobs (#877)
  * Added missing import into logger.py (#896)
  * Added type hints to CloudLoggingHandler constructor (#903)
  * Add summary_overview template (#878)
  * Changed table in web-framework-integration to bulleted list (#875)
  * Documentation update for OpenTelemetry (#915)
  * Update `dictConfig` snippet (#885)
- Adjust upstream source name in spec file
- Update BuildRequires and Requires from setup.py
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 3.10.0:
  * Allow users to explicitly configure universe domain
  * Added placeholder kwargs to StructuredLogHandler
  * Allowed for a partial override of loggers that get excluded
    from setup_client
  * Remove usage in including_default_value_fields to prepare for
    protobuf 5.x
  * Use value of cluster-location in GKE for tagging location
* Wed Dec 13 2023 Daniel Garcia <daniel.garcia@suse.com>
- Initial version (jsc#PED-6697)
